@@ -4,11 +4,9 @@
 #
 # Copyright, contact and other information can be found
 # at the bottom of this file, or by going to:
-# http://search.cpan.org/dist/Devel-NYTProf/
+# http://metacpan.org/release/Devel-NYTProf/
 #
 ###########################################################
-# $Id$
-###########################################################
 package Devel::NYTProf::Data;
 
 =head1 NAME
@@ -35,7 +33,7 @@ future versions).
 B<NOTE> the documentation is out of date and may not be updated soon.
 It's also likely that the API will change drastically in future.
 It's possible, for example, that the data model will switch to use SQLite
-and the http://search.cpan.org/perldoc?ORLite ORM.
+and the http://metacpan.org/pod/ORLite ORM.
 
 Let me know if you come to depend on a particular API and I'll try to preserve
 it if practical.
@@ -55,10 +53,7 @@ use Scalar::Util qw(blessed);
 use Devel::NYTProf::Core;
 use Devel::NYTProf::FileInfo;
 use Devel::NYTProf::SubInfo;
-use Devel::NYTProf::Util qw(
-    make_path_strip_editor strip_prefix_from_paths get_abs_paths_alternation_regex
-    trace_level
-);
+use Devel::NYTProf::Util qw( trace_level );
 
 our $VERSION = '4.02';
 
@@ -223,6 +218,10 @@ sub attributes {
     return shift->{attribute} || {};
 }
 
+sub options {
+    return shift->{option} || {};
+}
+
 sub subname_subinfo_map {
     return { %{ shift->{sub_subinfo} } }; # shallow copy
 }
@@ -309,7 +308,7 @@ sub packages_at_depth_subinfo {
         my @parts = split /::/, $fullpkgname; # drops empty trailing part
 
         # accumulate @$subinfos for the full package name
-        # and also for each succesive truncation of the package name
+        # and also for each successive truncation of the package name
         for (my $depth; $depth = @parts; pop @parts) {
             my $pkgname = join('::', @parts, '');
 
@@ -396,7 +395,7 @@ sub inc {
       separator  => "",
   } );
 
-Writes the profile data in a reasonably human friendly format to the sepcified
+Writes the profile data in a reasonably human friendly format to the specified
 C<filehandle> (default STDOUT).
 
 For non-trivial profiles the output can be very large. As a guide, there'll be
@@ -408,7 +407,7 @@ The types of data present can depend on the options used when profiling.
 
 If C<separator> is true then instead of whitespace, each item of data is
 indented with the I<path> through the structure with C<separator> used to
-separarate the elements of the path.
+separate the elements of the path.
 This format is especially useful for grep'ing and diff'ing.
 
 =cut
@@ -587,7 +586,12 @@ filenames: eval sequence numbers, like "(re_eval 2)" are changed to 0
 
 
 sub normalize_variables {
-    my $self       = shift;
+    my ($self, $normalize_options) = @_;
+
+    if ($normalize_options) {
+        %{ $self->options } = ();
+    }
+
     my $attributes = $self->attributes;
 
     for my $attr (qw(
