@@ -42,15 +42,7 @@ sub incl_time  { shift->[NYTP_SIi_INCL_RTIME] }
 
 sub excl_time  { shift->[NYTP_SIi_EXCL_RTIME] }
 
-sub subname    {
-    my $subname = shift->[NYTP_SIi_SUB_NAME];
-    return $subname if not ref $subname;
-    # the subname of a merged sub is a ref to an array of the merged subnames
-    # XXX could be ref to an array of the merged subinfos
-    # XXX or better to add a separate accessor instead of abusing subname like this
-    return $subname if not defined(my $join = shift);
-    return join $join, @$subname;
-}
+sub subname    { shift->[NYTP_SIi_SUB_NAME] }
 
 sub subname_without_package {
     my $subname = shift->[NYTP_SIi_SUB_NAME];
@@ -187,16 +179,15 @@ sub _alter_called_by_fileinfo {
 
             warn sprintf "_alter_called_by_fileinfo: %s from fid %d to fid %d\n",
                     $self->subname, $remove_fid, $new_fid
-                if trace_level();
+                if trace_level() >= 4;
 
             # merge $cb into $new_cb
             while ( my ($line, $cb_li) = each %$cb ) {
                 my $dst_line_info = $new_cb->{$line} ||= [];
-                _merge_in_caller_info($dst_line_info, delete $cb->{$line},
+                _merge_in_caller_info($dst_line_info, $cb->{$line},
                     tag => "$line:".$self->subname,
                 );
             }
-
         }
     }
 
@@ -216,7 +207,7 @@ sub merge_in {
 
     warn sprintf "Merging sub %s into %s (%s)\n",
             $donor_subname, $self_subname, join(" ", %opts)
-        if trace_level();
+        if trace_level() >= 4;
 
     # see also "case NYTP_TAG_SUB_CALLERS:" in load_profile_data_from_stream()
     push @{ $self->meta->{merged_sub_names} }, $donor->subname;
@@ -264,10 +255,10 @@ sub _merge_in_caller_info {
         return;
     }
 
-    if (trace_level()) {
+    if (trace_level() >= 5) {
         carp sprintf "_merge_in_caller_info%s merging from $src_line_info -> $dst_line_info:", $tag;
-        warn sprintf " . %s\n", fmt_sc($src_line_info);
-        warn sprintf " + %s\n", fmt_sc($dst_line_info);
+        warn sprintf " . %s\n", _fmt_sc($src_line_info);
+        warn sprintf " + %s\n", _fmt_sc($dst_line_info);
     }
     if (!@$dst_line_info) {
         @$dst_line_info = (0) x NYTP_SCi_elements;
@@ -288,13 +279,13 @@ sub _merge_in_caller_info {
     my $dst_cs = $dst_line_info->[NYTP_SCi_CALLING_SUB]||={};
     $dst_cs->{$_} = $src_cs->{$_} for keys %$src_cs;
 
-    warn sprintf " = %s\n", fmt_sc($dst_line_info)
-        if trace_level();
+    warn sprintf " = %s\n", _fmt_sc($dst_line_info)
+        if trace_level() >= 5;
 
     return;
 }
 
-sub fmt_sc {
+sub _fmt_sc {
     my ($sc) = @_;
     return "(empty)" if !@$sc;
     my $dst_cs = $sc->[NYTP_SCi_CALLING_SUB]||{};
@@ -401,7 +392,7 @@ sub dump {
     for my $cp (@caller_places) {
         my ($fid, $line, $sc) = @$cp;
         my @sc = @$sc;
-        $sc[NYTP_SCi_CALLING_SUB] = join "|", keys %{ $sc[NYTP_SCi_CALLING_SUB] };
+        $sc[NYTP_SCi_CALLING_SUB] = join "|", sort keys %{ $sc[NYTP_SCi_CALLING_SUB] };
         printf $fh "%s%s%s%d:%d%s[ %s ]\n",
             $prefix,
             'called_by', $separator,
